==> nomachine-7.6.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXDbus.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXDbus;no warnings;require Common::NXShellCommands;require 
PhysicSessions;((%buses)={});(my $NotDisplayFound=(-(0x0801+ 3104-0x1420)));my (
%XServer);(my (@allProcessArray)=());my (@XSessions);(my $dbusLibraryInitialized
=(-(0x11f9+ 2271-0x1ad7)));sub initialize{(my $dbusName=shift (@_));if ((
$dbusLibraryInitialized!=(-(0x2098+ 293-0x21bc)))){return;}Logger::debug (
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x49\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x20\x73\x74\x61\x72\x74\x2e"
);(my $ret=libnxhs::NXDBusInitialize ($dbusName,(0x06b2+ 1406-0x0c30)));
Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x49\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$ret)."\x27\x2e"));if (($ret==(0x122a+ 3119-0x1e59))){Logger::debug (
"\x44\x42\x75\x73\x20\x62\x79\x20\x6c\x69\x62\x6e\x78\x68\x73\x20\x65\x6e\x61\x62\x6c\x65\x64\x2e"
);($dbusLibraryInitialized=(0x105c+ 3032-0x1c33));return;}Logger::debug (
"\x44\x42\x75\x73\x20\x62\x79\x20\x6c\x69\x62\x6e\x78\x68\x73\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);($dbusLibraryInitialized=(0x1824+ 2926-0x2392));}sub destroy{if ((
$dbusLibraryInitialized==(0x0ecc+ 2656-0x192b))){Logger::debug (
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x44\x65\x73\x74\x72\x6f\x79\x20\x73\x74\x61\x72\x74\x2e"
);(my $ret=libnxhs::NXDBusDestroy ());Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x49\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x44\x42\x75\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$ret)."\x27\x2e"));Logger::debug (
"\x44\x42\x75\x73\x20\x6c\x69\x62\x72\x61\x72\x79\x20\x75\x6e\x6c\x6f\x61\x64\x65\x64\x2e"
);}}sub dbusByNXPLInitialized{if (($dbusLibraryInitialized==(-
(0x136c+ 3277-0x2038)))){return ((0x0eb6+ 4099-0x1eb9));}return (
$dbusLibraryInitialized);}sub checkBuses{Logger::debug (
"\x63\x68\x65\x63\x6b\x42\x75\x73\x65\x73\x20\x73\x74\x61\x72\x74\x65\x64\x2e");
(my (@names)=getSystemBusNames ());foreach my $item (@names){(my $pid=
getConnectionProcessId ($item));if (defined ($pid)){($buses{$item}{
"\x70\x69\x64"}=$pid);}}getConnectionProcessNames ();Logger::debug (
"\x42\x55\x53\x20\x6c\x69\x73\x74\x3a");foreach my $bus (keys (%buses)){(my $pid
=$buses{$bus}{"\x70\x69\x64"});(my $command=$buses{$bus}{
"\x63\x6f\x6d\x6d\x61\x6e\x64"});if (defined ($command)){Logger::debug (((((((
"\x42\x55\x53\x20".$bus)."\x20\x72\x75\x6e\x20\x62\x79\x20\x27").$pid).
"\x20\x2d\x20").$command)."\x27\x2e"));}}}sub getConnectionProcessNames{(my (
@command)=($GLOBAL::COMMAND_PS,"\x2d\x41","\x2d\x6f",
"\x70\x69\x64\x2c\x63\x6f\x6d\x6d\x61\x6e\x64"));(my (@options)=());(my (
$cmd_err,$cmd_out,$exit_value)=main::run_command ((\@command),(\@options)));(my (
@processes)=split ( /\n/ ,$cmd_out,(0x06d0+ 6127-0x1ebf)));foreach my $item (
@processes){if (($item=~ /^\s+(\d+)\s+(.*)/ )){(my $pid=$1);(my $command=$2);
foreach my $bus (keys (%buses)){if (($buses{$bus}{"\x70\x69\x64"}==$pid)){(
$buses{$bus}{"\x63\x6f\x6d\x6d\x61\x6e\x64"}=$command);}}}}}sub 
getConnectionProcessId{(my $connection=shift (@_));(my $answer=dbusSend (
"\x73\x79\x73\x74\x65\x6d",
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x42\x75\x73"
,
"\x2f\x6f\x72\x67\x2f\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2f\x44\x42\x75\x73"
,
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x42\x75\x73"
,
"\x47\x65\x74\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x55\x6e\x69\x78\x50\x72\x6f\x63\x65\x73\x73\x49\x44"
,("\x73\x74\x72\x69\x6e\x67\x3a".$connection)));Logger::debug (((
"\x67\x65\x74\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x50\x72\x6f\x63\x65\x73\x73\x49\x64\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$answer)."\x27\x2e"));if (($answer=~ /uint32 (\d+)/ )){return ($1);}else{return
 (undef);}}sub getSystemBusNames{(my $answer=dbusSend (
"\x73\x79\x73\x74\x65\x6d",
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x42\x75\x73"
,
"\x2f\x6f\x72\x67\x2f\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2f\x44\x42\x75\x73"
,
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x42\x75\x73"
,"\x4c\x69\x73\x74\x4e\x61\x6d\x65\x73"));Logger::debug3 (((
"\x44\x42\x75\x73\x20\x67\x65\x74\x53\x79\x73\x74\x65\x6d\x42\x75\x73\x4e\x61\x6d\x65\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$answer)."\x27\x2e"));(my (@lines)=split ( /\n/ ,$answer,(0x0a2b+ 3401-0x1774))
);(my (@names)=());foreach my $item (@lines){if (($item=~ /string "(.*)"/ )){(my $name
=$1);push (@names,$name);}}Logger::debug3 (((
"\x44\x42\x75\x73\x20\x67\x65\x74\x53\x79\x73\x74\x65\x6d\x42\x75\x73\x4e\x61\x6d\x65\x73\x20\x67\x6f\x74\x20\x27"
.join ($",@names))."\x27\x2e"));return (@names);}sub dbusSend{(my $type=shift (
@_));(my $destination=shift (@_));(my $objectPath=shift (@_));(my $interface=
shift (@_));(my $member=shift (@_));(my (@options)=@_);if (dbusByNXPLInitialized
 ()){(my $bufferSize=(0x147c+ 2560-0x0e7c));my ($buffer);my ($data);if (scalar (
@options)){($data=join ($",@options));}else{($data=(""));}Logger::debug ((((((((
(((((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x4d\x65\x74\x68\x6f\x64\x28"
.$bufferSize)."\x2c\x20").$destination)."\x2c\x20").$objectPath)."\x2c\x20").
$interface)."\x2c\x20").$member)."\x2c\x20").$data).
"\x29\x20\x73\x74\x61\x72\x74\x2e"));(my $written=libnxhs::NXDBusMethod ($buffer
,$bufferSize,$destination,$objectPath,$interface,$member,$data));Logger::debug (
((((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x4d\x65\x74\x68\x6f\x64\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$written)."\x20\x27").$buffer)."\x27\x2e"));if (($written>$bufferSize)){(
$bufferSize=($written+(0x00d3+ 4701-0x132f)));($buffer=(""));Logger::debug (((((
((((((((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x4d\x65\x74\x68\x6f\x64\x28"
.$bufferSize)."\x2c\x20").$destination)."\x2c\x20").$objectPath)."\x2c\x20").
$interface)."\x2c\x20").$member)."\x2c\x20").$data).
"\x29\x20\x73\x74\x61\x72\x74\x2e"));($written=libnxhs::NXDBusMethod ($buffer,
$bufferSize,$destination,$objectPath,$interface,$member,$data));Logger::debug ((
(((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x4d\x65\x74\x68\x6f\x64\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$written)."\x20\x27").$buffer)."\x27\x2e"));}if (($written==(-
(0x0d41+ 5726-0x239e)))){Common::NXCore::reportErrorFromNXPL (((((((((((((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x4d\x65\x74\x68\x6f\x64\x28"
.$bufferSize)."\x2c\x20").$destination)."\x2c\x20").$objectPath)."\x2c\x20").
$interface)."\x2c\x20").$member)."\x2c\x20").$data).
"\x29\x20\x66\x61\x69\x6c\x65\x64\x2e"));}return ($buffer);}my (@command);if (
scalar (@options)){(@command=(Common::NXShellCommands::getCommand (
"\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"),("\x2d\x2d".$type),(
"\x2d\x2d\x64\x65\x73\x74\x3d".$destination),
"\x2d\x2d\x74\x79\x70\x65\x3d\x6d\x65\x74\x68\x6f\x64\x5f\x63\x61\x6c\x6c",
"\x2d\x2d\x70\x72\x69\x6e\x74\x2d\x72\x65\x70\x6c\x79",$objectPath,(($interface.
"\x2e").$member),@options));}else{(@command=(Common::NXShellCommands::getCommand
 ("\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"),("\x2d\x2d".$type),(
"\x2d\x2d\x64\x65\x73\x74\x3d".$destination),
"\x2d\x2d\x74\x79\x70\x65\x3d\x6d\x65\x74\x68\x6f\x64\x5f\x63\x61\x6c\x6c",
"\x2d\x2d\x70\x72\x69\x6e\x74\x2d\x72\x65\x70\x6c\x79",$objectPath,(($interface.
"\x2e").$member)));}(my (@param)="\x45\x52\x52\x69\x6e\x4f\x55\x54");(my (
$std_err,$std_out,$ret_val)=main::run_command ((\@command),(\@param)));return (
$std_out);}sub dbusMonitorAll{(my $stdin=shift (@_));(my $stdout=shift (@_));(my $type
=shift (@_));(my (@command)=());(my (@param)=());(my $processPid=());(@command=(
Common::NXShellCommands::getCommand (
"\x64\x62\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72"),("\x2d\x2d".$type)));push (
@param,"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x69\x6e",$stdin);push (@param,
"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x6f\x75\x74",$stdout);push (@param,
"\x67\x65\x74\x20\x70\x69\x64",(\$processPid));push (@param,
"\x72\x75\x6e\x20\x69\x6e\x20\x62\x67");(my ($std_err,$std_out,$ret_val)=
main::run_command ((\@command),(\@param)));return ($processPid);}sub dbusMonitor
{(my $stdin=shift (@_));(my $stdout=shift (@_));(my $type=shift (@_));(my $property
=shift (@_));(my $sender=shift (@_));(my $interface=shift (@_));(my $member=
shift (@_));(my (@command)=());(my (@param)=());(my $processPid=());(my $parameterLine
=setMonitorParameterline ($property,$sender,$interface,$member));(@command=(
Common::NXShellCommands::getCommand (
"\x64\x62\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72"),("\x2d\x2d".$type),
$parameterLine));push (@param,"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x69\x6e"
,$stdin);push (@param,"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x6f\x75\x74",
$stdout);push (@param,"\x67\x65\x74\x20\x70\x69\x64",(\$processPid));push (
@param,"\x72\x75\x6e\x20\x69\x6e\x20\x62\x67");(my ($std_err,$std_out,$ret_val)=
main::run_command ((\@command),(\@param)));return ($processPid);}sub 
setMonitorParameterline{(my $property=shift (@_));(my $sender=shift (@_));(my $interface
=shift (@_));(my $member=shift (@_));(my $line=(""));if (($property ne (""))){(
$line=(("\x74\x79\x70\x65\x3d\x27".$property)."\x27"));}if (($sender ne (""))){
if (($line ne (""))){($line.=(("\x2c\x20\x73\x65\x6e\x64\x65\x72\x3d\x27".
$sender)."\x27"));}else{($line=(("\x73\x65\x6e\x64\x65\x72\x3d\x27".$sender).
"\x27"));}}if (($interface ne (""))){if (($line ne (""))){($line.=((
"\x2c\x20\x69\x6e\x74\x65\x72\x66\x61\x63\x65\x3d\x27".$interface)."\x27"));}
else{($line=(("\x69\x6e\x74\x65\x72\x66\x61\x63\x65\x3d\x27".$interface)."\x27")
);}}if (($sender ne (""))){if (($line ne (""))){($line.=((
"\x2c\x20\x6d\x65\x6d\x62\x65\x72\x3d\x27".$member)."\x27"));}else{($line=((
"\x6d\x65\x6d\x62\x65\x72\x3d\x27".$member)."\x27"));}}Logger::debug3 (((
"\x44\x42\x75\x73\x20\x50\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x6c\x69\x6e\x65\x20\x66\x6f\x72\x20\x64\x62\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$line)."\x27\x2e"));return ($line);}"\x3f\x3f\x3f";

==> nomachine-7.7.4-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXDbus.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXDbus;no warnings;require Common::NXShellCommands;require 
PhysicSessions;((%buses)={});(my $NotDisplayFound=(-(0x0f77+ 753-0x1267)));my (
%XServer);(my (@allProcessArray)=());my (@XSessions);(my $dbusLibraryInitialized
=(-(0x0cdb+ 5980-0x2436)));sub initialize{(my $dbusName=shift (@_));if ((
$dbusLibraryInitialized!=(-(0x00d6+ 1303-0x05ec)))){return;}Logger::debug (
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x49\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x20\x73\x74\x61\x72\x74\x2e"
);(my $ret=libnxhs::NXDBusInitialize ($dbusName,(0x1a95+ 2495-0x2454)));
Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x49\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$ret)."\x27\x2e"));if (($ret==(0x0028+ 2528-0x0a08))){Logger::debug (
"\x44\x42\x75\x73\x20\x62\x79\x20\x6c\x69\x62\x6e\x78\x68\x73\x20\x65\x6e\x61\x62\x6c\x65\x64\x2e"
);($dbusLibraryInitialized=(0x0b77+ 6762-0x25e0));return;}Logger::debug (
"\x44\x42\x75\x73\x20\x62\x79\x20\x6c\x69\x62\x6e\x78\x68\x73\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);($dbusLibraryInitialized=(0x08a6+ 6387-0x2199));}sub destroy{if ((
$dbusLibraryInitialized==(0x010c+ 5624-0x1703))){Logger::debug (
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x44\x65\x73\x74\x72\x6f\x79\x20\x73\x74\x61\x72\x74\x2e"
);(my $ret=libnxhs::NXDBusDestroy ());Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x49\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x44\x42\x75\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$ret)."\x27\x2e"));Logger::debug (
"\x44\x42\x75\x73\x20\x6c\x69\x62\x72\x61\x72\x79\x20\x75\x6e\x6c\x6f\x61\x64\x65\x64\x2e"
);}}sub dbusByNXPLInitialized{if (($dbusLibraryInitialized==(-
(0x04d4+ 1891-0x0c36)))){return ((0x00b4+ 4681-0x12fd));}return (
$dbusLibraryInitialized);}sub checkBuses{Logger::debug (
"\x63\x68\x65\x63\x6b\x42\x75\x73\x65\x73\x20\x73\x74\x61\x72\x74\x65\x64\x2e");
(my (@names)=getSystemBusNames ());foreach my $item (@names){(my $pid=
getConnectionProcessId ($item));if (defined ($pid)){($buses{$item}{
"\x70\x69\x64"}=$pid);}}getConnectionProcessNames ();Logger::debug (
"\x42\x55\x53\x20\x6c\x69\x73\x74\x3a");foreach my $bus (keys (%buses)){(my $pid
=$buses{$bus}{"\x70\x69\x64"});(my $command=$buses{$bus}{
"\x63\x6f\x6d\x6d\x61\x6e\x64"});if (defined ($command)){Logger::debug (((((((
"\x42\x55\x53\x20".$bus)."\x20\x72\x75\x6e\x20\x62\x79\x20\x27").$pid).
"\x20\x2d\x20").$command)."\x27\x2e"));}}}sub getConnectionProcessNames{(my (
@command)=($GLOBAL::COMMAND_PS,"\x2d\x41","\x2d\x6f",
"\x70\x69\x64\x2c\x63\x6f\x6d\x6d\x61\x6e\x64"));(my (@options)=());(my (
$cmd_err,$cmd_out,$exit_value)=main::run_command ((\@command),(\@options)));(my (
@processes)=split ( /\n/ ,$cmd_out,(0x044d+ 3842-0x134f)));foreach my $item (
@processes){if (($item=~ /^\s+(\d+)\s+(.*)/ )){(my $pid=$1);(my $command=$2);
foreach my $bus (keys (%buses)){if (($buses{$bus}{"\x70\x69\x64"}==$pid)){(
$buses{$bus}{"\x63\x6f\x6d\x6d\x61\x6e\x64"}=$command);}}}}}sub 
getConnectionProcessId{(my $connection=shift (@_));(my $answer=dbusSend (
"\x73\x79\x73\x74\x65\x6d",
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x42\x75\x73"
,
"\x2f\x6f\x72\x67\x2f\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2f\x44\x42\x75\x73"
,
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x42\x75\x73"
,
"\x47\x65\x74\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x55\x6e\x69\x78\x50\x72\x6f\x63\x65\x73\x73\x49\x44"
,("\x73\x74\x72\x69\x6e\x67\x3a".$connection)));Logger::debug (((
"\x67\x65\x74\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x50\x72\x6f\x63\x65\x73\x73\x49\x64\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$answer)."\x27\x2e"));if (($answer=~ /uint32 (\d+)/ )){return ($1);}else{return
 (undef);}}sub getSystemBusNames{(my $answer=dbusSend (
"\x73\x79\x73\x74\x65\x6d",
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x42\x75\x73"
,
"\x2f\x6f\x72\x67\x2f\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2f\x44\x42\x75\x73"
,
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x42\x75\x73"
,"\x4c\x69\x73\x74\x4e\x61\x6d\x65\x73"));Logger::debug3 (((
"\x44\x42\x75\x73\x20\x67\x65\x74\x53\x79\x73\x74\x65\x6d\x42\x75\x73\x4e\x61\x6d\x65\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$answer)."\x27\x2e"));(my (@lines)=split ( /\n/ ,$answer,(0x0415+ 4737-0x1696))
);(my (@names)=());foreach my $item (@lines){if (($item=~ /string "(.*)"/ )){(my $name
=$1);push (@names,$name);}}Logger::debug3 (((
"\x44\x42\x75\x73\x20\x67\x65\x74\x53\x79\x73\x74\x65\x6d\x42\x75\x73\x4e\x61\x6d\x65\x73\x20\x67\x6f\x74\x20\x27"
.join ($",@names))."\x27\x2e"));return (@names);}sub dbusSend{(my $type=shift (
@_));(my $destination=shift (@_));(my $objectPath=shift (@_));(my $interface=
shift (@_));(my $member=shift (@_));(my (@options)=@_);if (dbusByNXPLInitialized
 ()){(my $bufferSize=(0x1814+ 6244-0x2078));my ($buffer);my ($data);if (scalar (
@options)){($data=join ($",@options));}else{($data=(""));}Logger::debug ((((((((
(((((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x4d\x65\x74\x68\x6f\x64\x28"
.$bufferSize)."\x2c\x20").$destination)."\x2c\x20").$objectPath)."\x2c\x20").
$interface)."\x2c\x20").$member)."\x2c\x20").$data).
"\x29\x20\x73\x74\x61\x72\x74\x2e"));(my $written=libnxhs::NXDBusMethod ($buffer
,$bufferSize,$destination,$objectPath,$interface,$member,$data));Logger::debug (
((((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x4d\x65\x74\x68\x6f\x64\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$written)."\x20\x27").$buffer)."\x27\x2e"));if (($written>$bufferSize)){(
$bufferSize=($written+(0x04c6+ 3961-0x143e)));($buffer=(""));Logger::debug (((((
((((((((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x4d\x65\x74\x68\x6f\x64\x28"
.$bufferSize)."\x2c\x20").$destination)."\x2c\x20").$objectPath)."\x2c\x20").
$interface)."\x2c\x20").$member)."\x2c\x20").$data).
"\x29\x20\x73\x74\x61\x72\x74\x2e"));($written=libnxhs::NXDBusMethod ($buffer,
$bufferSize,$destination,$objectPath,$interface,$member,$data));Logger::debug ((
(((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x4d\x65\x74\x68\x6f\x64\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$written)."\x20\x27").$buffer)."\x27\x2e"));}if (($written==(-
(0x1b0c+ 2188-0x2397)))){Common::NXCore::reportErrorFromNXPL (((((((((((((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x44\x42\x75\x73\x4d\x65\x74\x68\x6f\x64\x28"
.$bufferSize)."\x2c\x20").$destination)."\x2c\x20").$objectPath)."\x2c\x20").
$interface)."\x2c\x20").$member)."\x2c\x20").$data).
"\x29\x20\x66\x61\x69\x6c\x65\x64\x2e"));}return ($buffer);}my (@command);if (
scalar (@options)){(@command=(Common::NXShellCommands::getCommand (
"\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"),("\x2d\x2d".$type),(
"\x2d\x2d\x64\x65\x73\x74\x3d".$destination),
"\x2d\x2d\x74\x79\x70\x65\x3d\x6d\x65\x74\x68\x6f\x64\x5f\x63\x61\x6c\x6c",
"\x2d\x2d\x70\x72\x69\x6e\x74\x2d\x72\x65\x70\x6c\x79",$objectPath,(($interface.
"\x2e").$member),@options));}else{(@command=(Common::NXShellCommands::getCommand
 ("\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"),("\x2d\x2d".$type),(
"\x2d\x2d\x64\x65\x73\x74\x3d".$destination),
"\x2d\x2d\x74\x79\x70\x65\x3d\x6d\x65\x74\x68\x6f\x64\x5f\x63\x61\x6c\x6c",
"\x2d\x2d\x70\x72\x69\x6e\x74\x2d\x72\x65\x70\x6c\x79",$objectPath,(($interface.
"\x2e").$member)));}(my (@param)="\x45\x52\x52\x69\x6e\x4f\x55\x54");(my (
$std_err,$std_out,$ret_val)=main::run_command ((\@command),(\@param)));return (
$std_out);}sub dbusMonitorAll{(my $stdin=shift (@_));(my $stdout=shift (@_));(my $type
=shift (@_));(my (@command)=());(my (@param)=());(my $processPid=());(@command=(
Common::NXShellCommands::getCommand (
"\x64\x62\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72"),("\x2d\x2d".$type)));push (
@param,"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x69\x6e",$stdin);push (@param,
"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x6f\x75\x74",$stdout);push (@param,
"\x67\x65\x74\x20\x70\x69\x64",(\$processPid));push (@param,
"\x72\x75\x6e\x20\x69\x6e\x20\x62\x67");(my ($std_err,$std_out,$ret_val)=
main::run_command ((\@command),(\@param)));return ($processPid);}sub dbusMonitor
{(my $stdin=shift (@_));(my $stdout=shift (@_));(my $type=shift (@_));(my $property
=shift (@_));(my $sender=shift (@_));(my $interface=shift (@_));(my $member=
shift (@_));(my (@command)=());(my (@param)=());(my $processPid=());(my $parameterLine
=setMonitorParameterline ($property,$sender,$interface,$member));(@command=(
Common::NXShellCommands::getCommand (
"\x64\x62\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72"),("\x2d\x2d".$type),
$parameterLine));push (@param,"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x69\x6e"
,$stdin);push (@param,"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x6f\x75\x74",
$stdout);push (@param,"\x67\x65\x74\x20\x70\x69\x64",(\$processPid));push (
@param,"\x72\x75\x6e\x20\x69\x6e\x20\x62\x67");(my ($std_err,$std_out,$ret_val)=
main::run_command ((\@command),(\@param)));return ($processPid);}sub 
setMonitorParameterline{(my $property=shift (@_));(my $sender=shift (@_));(my $interface
=shift (@_));(my $member=shift (@_));(my $line=(""));if (($property ne (""))){(
$line=(("\x74\x79\x70\x65\x3d\x27".$property)."\x27"));}if (($sender ne (""))){
if (($line ne (""))){($line.=(("\x2c\x20\x73\x65\x6e\x64\x65\x72\x3d\x27".
$sender)."\x27"));}else{($line=(("\x73\x65\x6e\x64\x65\x72\x3d\x27".$sender).
"\x27"));}}if (($interface ne (""))){if (($line ne (""))){($line.=((
"\x2c\x20\x69\x6e\x74\x65\x72\x66\x61\x63\x65\x3d\x27".$interface)."\x27"));}
else{($line=(("\x69\x6e\x74\x65\x72\x66\x61\x63\x65\x3d\x27".$interface)."\x27")
);}}if (($sender ne (""))){if (($line ne (""))){($line.=((
"\x2c\x20\x6d\x65\x6d\x62\x65\x72\x3d\x27".$member)."\x27"));}else{($line=((
"\x6d\x65\x6d\x62\x65\x72\x3d\x27".$member)."\x27"));}}Logger::debug3 (((
"\x44\x42\x75\x73\x20\x50\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x6c\x69\x6e\x65\x20\x66\x6f\x72\x20\x64\x62\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$line)."\x27\x2e"));return ($line);}"\x3f\x3f\x3f";
